/* Import plugin specific language pack */
tinyMCE.importPluginLanguagePack('wordpress', 'el,en');



// Plugin static class
var TinyMCE_WordPressPlugin = {
	getInfo : function() {
		return {
			longname : 'WordPress',
			author : 'WordPress, Raj Prasad',
			authorurl : 'http://www.rajprasad.net/',
			infourl : 'http://www.wordpress.org/',
			version : tinyMCE.majorVersion + "." + tinyMCE.minorVersion
		};
	},


	/**
	 * Executed on the initialization of a TinyMCE instance
	 */
	initInstance : function(inst) {
		if (!tinyMCE.settings['wordpress_skip_plugin_css'])
			tinyMCE.importCSS(inst.getDoc(), tinyMCE.baseURL + "/plugins/wordpress/wordpress.css");
	},
	
	
	/**
	 * Returns the HTML contents of the emotions control.
	 */
	getControlHTML : function(cn) {
		switch (cn) {
			case "more":
				return tinyMCE.getButtonHTML(cn, 'lang_wordpress_more_button', '{$pluginurl}/images/more.gif', 'mceWordPressMore', true);
			case "nextpage":
				return tinyMCE.getButtonHTML(cn, 'lang_wordpress_page_button', '{$pluginurl}/images/page.gif', 'mceWordPressPage', true);
		}

		return "";
	},
				

	/**
	 * Executes the WordPress plugin commands.
	 */
	execCommand : function(editor_id, element, command, user_interface, value) {
		var instance = tinyMCE.getInstanceById(editor_id);
		var focusElm = instance.getFocusElement();
		var doc = instance.getDoc();
		var flag = "";
		
		function getAttrib(elm, name) {
			return elm.getAttribute(name) ? elm.getAttribute(name) : "";
		}
		
		switch (command) {
			case "mceWordPressMore":
				// Is selection a image
				if (focusElm != null && focusElm.nodeName.toLowerCase() == "img") {
					flag = getAttrib(focusElm, 'class');
	
					if (flag != 'mce_plugin_wordpress_more') // Not a wordpress
						return true;
	
					action = "update";
				}
	
				var altMore = tinyMCE.getLang('lang_wordpress_more_alt');
				html = ''
					+ '<img src="' + (tinyMCE.getParam("theme_href") + "/images/spacer.gif") + '" '
					+ ' width="99%" height="10px" '
					+ 'alt="'+altMore+'" title="'+altMore+'" class="mce_plugin_wordpress_more" name="mce_plugin_wordpress_more" />';
					
				tinyMCE.execCommand("mceInsertContent", true, html);
				return true;
				
			case "mceWordPressPage":
				// Is selection a image
				if (focusElm != null && focusElm.nodeName.toLowerCase() == "img") {
					flag = getAttrib(focusElm, 'class');
	
					if (flag != 'mce_plugin_wordpress_page') // Not a wordpress
						return true;
	
					action = "update";
				}
	
				var altPage = tinyMCE.getLang('lang_wordpress_more_alt');
				html = ''
					+ '<img src="' + (tinyMCE.getParam("theme_href") + "/images/spacer.gif") + '" '
					+ ' width="99%" height="10px" '
					+ 'alt="'+altPage+'" title="'+altPage+'" class="mce_plugin_wordpress_page" name="mce_plugin_wordpress_page" />';
				tinyMCE.execCommand("mceInsertContent",true,html);
				return true;
		}
		
		// Pass to next handler in chain
		return false;
	},
	
	
	/**
	 * Called when the cursor or selection changes in TinyMCE.
	 */
	handleNodeChange : function(editor_id, node, undo_index, undo_levels, visual_aid, any_selection) {
	},
	
	
	/**
	 * Called when HTML contents are inserted or retrived from a instance, including when it is saved
	 */
	cleanup : function(type, content, inst) {
		
		
		function parseAttributes(attribute_string) {
			var attributeName = "";
			var attributeValue = "";
			var withInName;
			var withInValue;
			var attributes = new Array();
			var whiteSpaceRegExp = new RegExp('^[ \n\r\t]+', 'g');
			var titleText = tinyMCE.getLang('lang_wordpress_more');
			var titleTextPage = tinyMCE.getLang('lang_wordpress_page');
		
			if (attribute_string == null || attribute_string.length < 2)
				return null;
		
			withInName = withInValue = false;
		
			for (var i=0; i<attribute_string.length; i++) {
				var chr = attribute_string.charAt(i);
		
				if ((chr == '"' || chr == "'") && !withInValue)
					withInValue = true;
				else if ((chr == '"' || chr == "'") && withInValue) {
					withInValue = false;
		
					var pos = attributeName.lastIndexOf(' ');
					if (pos != -1)
						attributeName = attributeName.substring(pos+1);
		
					attributes[attributeName.toLowerCase()] = attributeValue.substring(1).toLowerCase();
		
					attributeName = "";
					attributeValue = "";
				} else if (!whiteSpaceRegExp.test(chr) && !withInName && !withInValue)
					withInName = true;
		
				if (chr == '=' && withInName)
					withInName = false;
		
				if (withInName)
					attributeName += chr;
		
				if (withInValue)
					attributeValue += chr;
			}
		
			return attributes;
		}
		
		switch (type) {
	
		case "insert_to_editor":
			var startPos = 0;
			var altMore = tinyMCE.getLang('lang_wordpress_more_alt');
			var altPage = tinyMCE.getLang('lang_wordpress_page_alt');

			// Parse all <!--more--> tags and replace them with images
			while ((startPos = content.indexOf('<!--more-->', startPos)) != -1) {
				// Insert image
				var contentAfter = content.substring(startPos + 11);
				content = content.substring(0, startPos);
				content += '<img src="' + (tinyMCE.getParam("theme_href") + "/images/spacer.gif") + '" ';
				content += ' width="100%" height="10px" ';
				content += 'alt="'+altMore+'" title="'+altMore+'" class="mce_plugin_wordpress_more" />';
				content += contentAfter;

				startPos++;
			}
			var startPos = 0;

			// Parse all <!--page--> tags and replace them with images
			while ((startPos = content.indexOf('<!--nextpage-->', startPos)) != -1) {
				// Insert image
				var contentAfter = content.substring(startPos + 15);
				content = content.substring(0, startPos);
				content += '<img src="' + (tinyMCE.getParam("theme_href") + "/images/spacer.gif") + '" ';
				content += ' width="100%" height="10px" ';
				content += 'alt="'+altPage+'" title="'+altPage+'" class="mce_plugin_wordpress_page" />';
				content += contentAfter;

				startPos++;
			}

			break;

		case "get_from_editor":
			// Parse all img tags and replace them with <!--more-->
			var startPos = -1;
			while ((startPos = content.indexOf('<img', startPos+1)) != -1) {
				var endPos = content.indexOf('/>', startPos);
				var attribs = parseAttributes(content.substring(startPos + 4, endPos));

				if (attribs['class'] == "mce_plugin_wordpress_more") {
					endPos += 2;
	
					var embedHTML = '<!--more-->';
	
					// Insert embed/object chunk
					chunkBefore = content.substring(0, startPos);
					chunkAfter = content.substring(endPos);
					content = chunkBefore + embedHTML + chunkAfter;
				}
				if (attribs['class'] == "mce_plugin_wordpress_page") {
					endPos += 2;
	
					var embedHTML = '<!--nextpage-->';
	
					// Insert embed/object chunk
					chunkBefore = content.substring(0, startPos);
					chunkAfter = content.substring(endPos);
					content = chunkBefore + embedHTML + chunkAfter;
				}
			}

			// Remove anonymous, empty paragraphs.
			content = content.replace(new RegExp('<p>(\\s|&nbsp;)*</p>', 'mg'), '');

			// Handle table badness.
			content = content.replace(new RegExp('<(table( [^>]*)?)>.*?<((tr|thead)( [^>]*)?)>', 'mg'), '<$1><$3>');
			content = content.replace(new RegExp('<(tr|thead|tfoot)>.*?<((td|th)( [^>]*)?)>', 'mg'), '<$1><$2>');
			content = content.replace(new RegExp('</(td|th)>.*?<(td( [^>]*)?|th( [^>]*)?|/tr|/thead|/tfoot)>', 'mg'), '</$1><$2>');
			content = content.replace(new RegExp('</tr>.*?<(tr|/table)>', 'mg'), '</tr><$1>');
			content = content.replace(new RegExp('<(/?(table|tbody|tr|th|td)[^>]*)>(\\s*|(<br ?/?>)*)*', 'g'), '<$1>');

			// Pretty it up for the source editor.
			var blocklist = 'blockquote|ul|ol|li|table|thead|tr|th|td|div|h\\d|pre|p';
			content = content.replace(new RegExp('\\s*</('+blocklist+')>\\s*', 'mg'), '</$1>\n');
			content = content.replace(new RegExp('\\s*<(('+blocklist+')[^>]*)>\\s*', 'mg'), '\n<$1>');
			content = content.replace(new RegExp('<((li|/?tr|/?thead|/?tfoot)( [^>]*)?)>', 'g'), '\t<$1>');
			content = content.replace(new RegExp('<((td|th)( [^>]*)?)>', 'g'), '\t\t<$1>');
			content = content.replace(new RegExp('\\s*<br ?/?>\\s*', 'mg'), '<br />\n');
			content = content.replace(new RegExp('^\\s*', ''), '');
			content = content.replace(new RegExp('\\s*$', ''), '');
			
			break;
		}

	// Pass through to next handler in chain
		return content;
	}
	
	
	
};

// Register plugin
tinyMCE.addPlugin('wordpress', TinyMCE_WordPressPlugin);
